From: Nick Andrew <nick@nick-andrew.net>
To: Trivial Kernel Patches <trivial@kernel.org>
Cc: Linux Kernel Mailing List <linux-kernel@vger.kernel.org>
Subject: [TRIVIAL PATCH 08/11] Fix misspelling of "firmware" in qla1280.c
Date: Sat, 03 Jan 2009 18:57:37 +1100 [thread overview]
Message-ID: <20090103075727.27466.41093.stgit@marcab.local> (raw)
In-Reply-To: <20090103074923.27466.7287.stgit@marcab.local>
Fix misspelling of "firmware" in qla1280.c
It's spelled "firmware".
Signed-off-by: Nick Andrew <nick@nick-andrew.net>
---
drivers/scsi/qla1280.c | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)
diff --git a/drivers/scsi/qla1280.c b/drivers/scsi/qla1280.c
index b6cd12b..cc57a23 100644
--- a/drivers/scsi/qla1280.c
+++ b/drivers/scsi/qla1280.c
@@ -128,7 +128,7 @@
- Integrate ql12160_set_target_parameters() with 1280 version
- Make qla1280_setup() non static
- Do not call qla1280_check_for_dead_scsi_bus() on every I/O request
- sent to the card - this command pauses the firmare!!!
+ sent to the card - this command pauses the firmware!!!
Rev 3.23.15 Beta March 19, 2002, Jes Sorensen
- Clean up qla1280.h - remove obsolete QL_DEBUG_LEVEL_x definitions
- Remove a pile of pointless and confusing (srb_t **) and
@@ -659,7 +659,7 @@ static int qla1280_read_nvram(struct scsi_qla_host *ha)
/* The firmware interface is, um, interesting, in that the
* actual firmware image on the chip is little endian, thus,
* the process of taking that image to the CPU would end up
* little endian. However, the firmare interface requires it
* to be read a word (two bytes) at a time.
*
* The net result of this would be that the word (and
next prev parent reply other threads:[~2009-01-03 7:58 UTC|newest]
Thread overview: 13+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-01-03 7:49 [TRIVIAL PATCH 00/11] Fix misspelling of "firmware" Nick Andrew
2009-01-03 7:50 ` [TRIVIAL PATCH 01/11] Fix misspelled firmware in Kconfig Nick Andrew
2009-01-03 7:51 ` [TRIVIAL PATCH 02/11] Fix misspelling of "firmware" in atmel.c Nick Andrew
2009-01-03 7:52 ` [TRIVIAL PATCH 03/11] Fix misspelling of "firmware" in ipw2100.c Nick Andrew
2009-01-03 7:53 ` [TRIVIAL PATCH 04/11] Fix misspelling of "firmware" in acpi_memhotplug.c Nick Andrew
2009-01-03 7:54 ` [TRIVIAL PATCH 05/11] Fix misspelling of "firmware" in ql4_mbx.c Nick Andrew
2009-01-03 7:55 ` [TRIVIAL PATCH 06/11] Fix misspelling of "firmware" in megaraid.c Nick Andrew
2009-01-03 7:56 ` [TRIVIAL PATCH 07/11] Fix misspelling of "firmware" in a100u2w.c Nick Andrew
2009-01-03 7:57 ` Nick Andrew [this message]
2009-01-03 7:58 ` [TRIVIAL PATCH 09/11] Fix misspelling of "firmware" in usb.c Nick Andrew
2009-01-03 7:59 ` [TRIVIAL PATCH 10/11] Fix misspelling of "firmware" in powerpc Makefile Nick Andrew
2009-01-03 8:00 ` [TRIVIAL PATCH 11/11] Fix misspelling of "firmware" in docs for ncr53c8xx/sym53c8xx Nick Andrew
2009-01-03 23:23 ` [TRIVIAL PATCH 00/11] Fix misspelling of "firmware" Jiri Kosina
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20090103075727.27466.41093.stgit@marcab.local \
--to=nick@nick-andrew.net \
--cc=linux-kernel@vger.kernel.org \
--cc=trivial@kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -659,7 +659,7 @@ static int qla1280_read_nvram(struct scsi_qla_host *ha)
* actual firmware image on the chip is little endian, thus,
* the process of taking that image to the CPU would end up
- * little endian. However, the firmare interface requires it
+ * little endian. However, the firmware interface requires it
* to be read a word (two bytes) at a time.
*
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox